@@ -18,6 +18,12 @@
 
 import dbus
 
+def utf8(string):
+	if type(string) == str:
+		return unicode(string, "utf-8")
+	else:
+		return string
+
 class PlayerBase(object):
 	"""A base for player objects"""
 	
@@ -68,7 +74,7 @@ class PlayerBase(object):
 		pass
 	
 	def get_id(self):
-		return "%s-%s" %(self.name, unicode(self.version))
+		return "%s_%s" %(self.name.lower(), utf8(self.version).replace(".", "_"))
 		
 	def get_snapshot(self):
 		"""Returns a snapshots of all the values of this player."""
